#
# Gives us a git-style main command that calls subcommands.
#
# Copyright 2023-2024: Joe Block <jpb@unixorn.net>
# License: Apache 2.0


import os
import subprocess
import sys

from gitlike_commands import find_subcommand


def hmd_usage():
    """
    They called hdm with no subcommands, or we couldn't find a subcommand
    """
    myName = os.path.basename(sys.argv[0])
    print(f"{myName} calls subcommands - try '{myName} create device --help' for example.")


def hmd_driver():
    """
    Process the command line arguments, find and run the appropriate
    subcommand.

    We want to be able to do git-style handoffs to subcommands where if we
    do `hdm blah foo bar` and the executable `hdm-blah-foo` exists, we'll call
    it with the argument bar.

    We deliberately don't do anything with the arguments other than hand
    them off to the hdm subcommand found.

    Subcommands are responsible for their own argument parsing.
    """
    try:
        (command, args) = find_subcommand(sys.argv)

        # If we can't construct a subcommand from sys.argv, it'll still be able
        # to find this driver script, and re-running ourself isn't useful.
        if os.path.basename(command) == sys.argv[0]:
            print("Could not find a subcommand for %s" % " ".join(sys.argv))
            sys.exit(13)
    except RuntimeError as e:
        print(str(e))
        hmd_usage()
        sys.exit(13)
    subprocess.check_call([command] + args)


if __name__ == "__main__":
    hmd_driver()



#
# sensors.py
#
# Copyright 2022-2023, Joe Block <jpb@unixorn.net>

"""
Code to support the hmd-create-binary-sensor script
"""

import logging
import sys

from ha_mqtt_discoverable import __version__ as TOOL_VERSION
from ha_mqtt_discoverable.cli import create_base_parser
from ha_mqtt_discoverable.sensors import BinarySensor
from ha_mqtt_discoverable.settings import binary_sensor_settings


def binary_sensor_parser():
    parser = create_base_parser(description="Create a binary sensor on MQTT that will be autodiscovered by Home Assistant")
    parser.add_argument(
        "--state",
        type=str.upper,
        choices=["OFF", "ON"],
        help="Set the binary sensor's state",
    )
    parser.add_argument("--metric-name", type=str, required=True, help="What metric to create")
    return parser


def binary_sensor_cli():
    parser = binary_sensor_parser()
    cli = parser.parse_args()
    loglevel = getattr(logging, cli.log_level.upper(), None)
    logFormat = "[%(asctime)s][%(levelname)8s][%(filename)s:%(lineno)s - %(funcName)20s() ] %(message)s"
    logging.basicConfig(level=loglevel, format=logFormat)
    logging.info("Set log level to %s", cli.log_level.upper())
    return cli


def create_binary_sensor():
    """
    Create a binary sensor from the command line, and set its state.
    """
    cli = binary_sensor_cli()
    if cli.version:
        print(f"ha-mqtt-discoverable version {TOOL_VERSION}")
        sys.exit(0)
    logging.info(f"cli: {cli}")
    settings = binary_sensor_settings(path=cli.settings_file, cli=cli)
    logging.info(f"{settings}")
    sensor = BinarySensor(settings=settings)
    if cli.state == "ON":
        sensor.on()
    else:
        sensor.off()
